@@ -3,12 +3,18 @@
 bindtextdomain('check_quota', SM_PATH . 'plugins/check_quota/locale');
 textdomain('check_quota');
 
-
 if ( $_SERVER["SERVER_PORT"] == 80 )
 	$cq_proto = 'http://';
 elseif ( $_SERVER["SERVER_PORT"] == 443 )
 	$cq_proto = 'https://';
 
+$cq_server = $_SERVER["HTTP_HOST"];
+
+$cq_docroot = substr($_SERVER["SCRIPT_NAME"],0,strpos($_SERVER["SCRIPT_NAME"],"src/"));
+
+$cq_image_path = "$cq_docroot" . "/plugins/check_quota/images/";
+$cq_swf_path = "$cq_docroot" . "/plugins/check_quota/swf/";
+
 global $left_size;
 $cq_width = $left_size * 0.8;
 $cq_width = round("$cq_width");
@@ -34,7 +40,7 @@ if ( $cq_size_quota )
 	if ( $cq_show_quota_intro_text && empty($cq_intro_text) ) 
 		$cq_intro_text = _("Quota Usage:");
 
-	echo '<div align="center"><font size="' . $cq_font_size . '"><br>' . "\n";
+	echo '<div align="' . $cq_graph_align . '"><font size="' . $cq_font_size . '"><br>' . "\n";
 
 	if ( $cq_show_filesystems && !empty($cq_fsname) )
 		echo "  $cq_fsname" . '<br>' . "\n";
